This class implements a Farrington-Manning test for non-inferiority
trials. A trial with binary outcomes in two groups E and
C is assumed. The null and alternative hypotheses for the
non-inferiority of response probabilities are:
$$H_0: p_E - p_C \leq -\delta \textrm{ vs. } H_1: p_E - p_C > -\delta,$$
where \(\delta\) denotes the non-inferiority margin.
The function setupFarringtonManning creates an object of
FarringtonManning.
setupFarringtonManning(alpha, beta, r = 1, delta, delta_NI, n_max = Inf, ...)An object of class FarringtonManning.
One-sided type I error rate.
Type II error rate.
Allocation ratio between experimental and control group.
Difference of effect size between alternative and null hypothesis.
Non-inferiority margin.
Maximal overall sample size. If the recalculated sample size
is greater than n_max it is set to n_max.
Further optional arguments.
The nuisance parameter is the overall response probability \(p_0\). In the blinded sample size recalculation procedure it is blindly estimated by: $$\hat{p}_0 := (X_{1,E} + X_{1,C}) / (n_{1,E} + n_{1,C}),$$ where \(X_{1,E}\) and \(X_{1,C}\) are the numbers of responses and \(n_{1,E}\) and \(n_{1,C}\) are the sample sizes of the respective group after the first stage. The event rates in both groups under the alternative hypothesis can then be blindly estimated as: $$\hat{p}_{C,A} := \hat{p}_0 - \Delta \cdot r / (1 + r) \textrm{, } \hat{p}_{E,A} := \hat{p}_0 + \Delta / (1 + r),$$ where \(\Delta\) is the difference in response probabilities under the alternative hypothesis and r is the allocation ratio of the sample sizes in the two groups. These blinded estimates can then be used to re-estimate the sample size.
Friede, T., Mitchell, C., & Mueller-Velten, G. (2007). Blinded sample size
reestimation in non-inferiority trials with binary endpoints.
Biometrical Journal, 49(6), 903-916.
Kieser, M. (2020). Methods and applications of sample size calculation and
recalculation in clinical trials. Springer.
design <- setupFarringtonManning(alpha = .025, beta = .2, r = 1, delta = 0,
delta_NI = .15)
Run the code above in your browser using DataLab