This method returns an adjusted significance level that can be used
such that the actual type I error rate is preserved.
Usage
adjusted_alpha(design, n1, nuisance, ...)
Value
Value of the adjusted significance level
for every nuisance parameter and every value of n1.
Arguments
design
object of class TestStatistic created by setup
n1
total number of patients that are recruited before the sample size
is recalculated
nuisance
nuisance parameter that is estimated at the interim analysis
...
Further optional arguments.
Details
The method is only vectorized in either nuisance
or n1.
The method is implemented for the classes Student,
ChiSquare, and FarringtonManning.
Check the class-specific documentation for further parameters that have
to be specified.