Value of the adjusted significance level for every
nuisance parameter and every value of n1.
Arguments
design
Object of class ChiSquare created by setupChiSquare.
n1
Either the sample size of the first stage (if
recalculation = TRUE or the total sample size (if
recalculation = FALSE).
nuisance
Value of the nuisance parameter in (0,1). For the
Chi-Squared test this is the overall response rate.
recalculation
Should the sample size be recalculated after n1
patients are recruited?
nuis_ass
If recalculation = FALSE this is the value for
the overall response rate that is used to calculate the sample size
for the adjusted significance level.
precision
Value by which the nominal type 1 error rate is
reduced in each iteration until the nominal type 1 error rate is
preserved.
gamma
If gamma > 0 then the significance level is adjusted
such that the actual level is at most alpha - gamma. This is
necessary to maintain the nomininal significance level if a confidence
interval approach proposed by Friede & Kieser (2011) is used.
allocation
Whether the allocation ratio should be preserved
exactly (exact) or approximately (approximate
or kf_approx). appproximate uses the unrounded calculated
sample size in the sample size recalculation, kf_approx
rounds the sample size to the next integer.
...
Further optional arguments.
Details
The method is only vectorized in either nuisance
or n1.