n_dist,ChiSquare-method: Distribution of the Sample Size
Description
Calculates the distribution of the total sample sizes of designs
with blinded sample size recalculation for different values of the
nuisance parameter or of n1.
Summary and/or plot of the sample size distribution for
every nuisance parameter and every value of n1.
Arguments
design
Object of class ChiSquare created by setupChiSquare.
n1
Either the sample size of the first stage (if
recalculation = TRUE or the total sample size (if
recalculation = FALSE).
nuisance
Value of the nuisance parameter in (0,1). For the
Chi-Squared test this is the overall response rate.
summary
Is a summary of the sample size distribution desired?
Otherwise, a vector with sample sizes is returned.
plot
Should a plot of the sample size distribution be drawn?
allocation
Whether the allocation ratio should be preserved
exactly (exact) or approximately (approximate
or kf_approx). appproximate uses the unrounded calculated
sample size in the sample size recalculation, kf_approx
rounds the sample size to the next integer.
...
Further optional arguments.
Details
Only sample sizes that occur with a probability of at least 0.01
are considered.
The method is only vectorized in either nuisance
or n1.