powered by
Calculates the distribution of the total sample sizes of designs with blinded sample size recalculation for different values of the nuisance parameter or of n1.
# S4 method for FarringtonManning n_dist( design, n1, nuisance, summary, plot, allocation = c("exact", "approximate"), ... )
Summary and/or plot of the sample size distribution for each nuisance parameter and every value of n1.
Object of class FarringtonManning created by setupFarringtonManning.
FarringtonManning
setupFarringtonManning
Either the sample size of the first stage (if recalculation = TRUE or the total sample size (if recalculation = FALSE).
recalculation = TRUE
recalculation = FALSE
Value of the nuisance parameter in (0,1). For the Farrington-Manning test this is the overall response rate.
Is a summary of the sample size distribution desired? Otherwise, a vector with sample sizes is returned.
Should a plot of the sample size distribution be drawn?
Whether the allocation ratio should be preserved exactly (exact) or approximately (approximate).
exact
approximate
Further optional arguments.
Only sample sizes that occur with a probability of at least 0.01 are considered.
The method is only vectorized in either nuisance or n1.
nuisance
n1
d <- setupFarringtonManning(alpha = 0.025, beta = 0.2, r = 1, delta = 0, delta_NI = 0.25) n_dist(d, n1 = 30, nuisance = 0.2, summary = TRUE, plot = FALSE)
Run the code above in your browser using DataLab