Learn R Programming

blindrecalc (version 1.1.0)

n_fix,Student-method: Fixed Sample Size

Description

Returns the sample size of a fixed design without sample size recalculation.

Usage

# S4 method for Student
n_fix(design, nuisance, ...)

Value

One value of the fixed sample size for every nuisance parameter and every value of n1.

Arguments

design

test statistic object

nuisance

nuisance parameter

...

Further optional arguments.

Details

The method is only vectorized in either nuisance or n1.

Examples

Run this code
d <- setupStudent(alpha = .025, beta = .2, r = 1, delta = 3.5, delta_NI = 0,
                  alternative = "greater", n_max = 156)
n_fix(design = d, nuisance = 5.5)

Run the code above in your browser using DataLab