powered by
Returns the sample size of a fixed design without sample size recalculation.
# S4 method for ChiSquare n_fix( design, nuisance, variance = c("heterogeneous", "homogeneous"), rounded = TRUE, ... )
One value of the fixed sample size for every nuisance parameter and every value of n1.
Object of class ChiSquare created by setupChiSquare.
ChiSquare
setupChiSquare
Value of the nuisance parameter. For the Chi-Squared test this is the overall response rate.
A character string indicating whether the "heterogenous" (default) or the "homogeneous" variance formula should be used.
heterogenous
homogeneous
Whether the calculated sample size should be rounded up such that the allocation ratio is preserved.
Further optional arguments.
The method is only vectorized in either nuisance or n1.
nuisance
n1
design1 <- setupChiSquare(alpha = 0.025, beta = 0.2, r = 1, delta = 0.2) n_fix(design1, nuisance = c(0.2, 0.3))
Run the code above in your browser using DataLab