powered by
Returns the sample size of a fixed design without sample size recalculation.
# S4 method for FarringtonManning n_fix(design, nuisance, rounded = TRUE, ...)
One value of the fixed sample size for every nuisance parameter and every value of n1.
Object of class FarringtonManning created by setupFarringtonManning.
FarringtonManning
setupFarringtonManning
Value of the nuisance parameter. For the Farrington-Manning test this is the overall response rate.
Whether the calculated sample size should be rounded up such that the allocation ratio is preserved.
Further optional arguments.
The method is only vectorized in either nuisance or n1.
nuisance
n1
d <- setupFarringtonManning(alpha = 0.025, beta = 0.2, r = 1, delta = 0, delta_NI = 0.25) n_fix(d, nuisance = 0.3)
Run the code above in your browser using DataLab