powered by
Returns the sample size of a fixed design without sample size recalculation.
# S4 method for Student n_fix(design, nuisance, ...)
One value of the fixed sample size for every nuisance parameter and every value of n1.
test statistic object
nuisance parameter
Further optional arguments.
The method is only vectorized in either nuisance or n1.
nuisance
n1
d <- setupStudent(alpha = .025, beta = .2, r = 1, delta = 3.5, delta_NI = 0, alternative = "greater", n_max = 156) n_fix(design = d, nuisance = 5.5)
Run the code above in your browser using DataLab