powered by
Calculates the power of designs with blinded sample size recalculation or of fixed designs for one or several values of the nuisance parameter.
pow(design, n1, nuisance, recalculation, ...)
One power value for every nuisance parameter and every value of n1.
object of class TestStatistic created by setup
TestStatistic
setup
total number of patients that are recruited before the sample size is recalculated
nuisance parameter that is estimated at the interim analysis
Should the sample size be recalculated after n1 patients are recruited?
Further optional arguments.
The method is only vectorized in either nuisance or n1.
nuisance
n1
The method is implemented for the classes Student, ChiSquare, and FarringtonManning.
Student
ChiSquare
FarringtonManning
d <- setupStudent(alpha = .025, beta = .2, r = 1, delta = 3.5, delta_NI = 0, alternative = "greater", n_max = 156) pow(d, n1 = 20, nuisance = 5.5, recalculation = TRUE)
Run the code above in your browser using DataLab