Learn R Programming

blindrecalc (version 1.1.0)

pow,ChiSquare-method: Power

Description

Calculates the power of designs with blinded sample size recalculation or of fixed designs for one or several values of the nuisance parameter.

Usage

# S4 method for ChiSquare
pow(
  design,
  n1,
  nuisance,
  recalculation,
  allocation = c("exact", "approximate", "kf_approx"),
  ...
)

Value

One power value for every nuisance parameter and every value of n1.

Arguments

design

Object of class ChiSquare created by setupChiSquare.

n1

Either the sample size of the first stage (if recalculation = TRUE or the total sample size (if recalculation = FALSE).

nuisance

Value of the nuisance parameter in (0,1). For the Chi-Squared test this is the overall response rate.

recalculation

Should the sample size be recalculated after n1 patients are recruited?

allocation

Whether the allocation ratio should be preserved exactly (exact) or approximately (approximate or kf_approx). appproximate uses the unrounded calculated sample size in the sample size recalculation, kf_approx rounds the sample size to the next integer.

...

Further optional arguments.

Details

The method is only vectorized in either nuisance or n1.

Examples

Run this code
  d <- setupChiSquare(alpha = 0.025, beta = 0.2, r = 1, delta = 0.2)
  pow(d, n1 = 20, nuisance = c(0.2, 0.4), recalculation = TRUE)

Run the code above in your browser using DataLab