One power value for every nuisance parameter and every value of n1.
Arguments
design
Object of class ChiSquare created by setupChiSquare.
n1
Either the sample size of the first stage (if
recalculation = TRUE or the total sample size (if
recalculation = FALSE).
nuisance
Value of the nuisance parameter in (0,1). For the
Chi-Squared test this is the overall response rate.
recalculation
Should the sample size be recalculated after n1
patients are recruited?
allocation
Whether the allocation ratio should be preserved
exactly (exact) or approximately (approximate
or kf_approx). appproximate uses the unrounded calculated
sample size in the sample size recalculation, kf_approx
rounds the sample size to the next integer.
...
Further optional arguments.
Details
The method is only vectorized in either nuisance
or n1.