Computes the type I error rate of designs with blinded sample size recalculation
or of fixed designs for one or several values of the nuisance parameter.
Usage
toer(design, n1, nuisance, recalculation, ...)
Value
One type I error rate value for every nuisance parameter and every value of n1.
Arguments
design
object of class TestStatistic created by setup
n1
total number of patients that are recruited before the sample size
is recalculated
nuisance
nuisance parameter that is estimated at the interim analysis
recalculation
Should the sample size be recalculated after n1
patients are recruited?
...
Further optional arguments.
Details
The method is only vectorized in either nuisance
or n1.
The method is implemented for the classes Student,
ChiSquare, and FarringtonManning.